package cn.rankin.apiweb.security;

import cn.rankin.common.utils.util.ListUtil;
import com.alibaba.fastjson.JSON;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Jwts;
import org.apache.commons.lang.StringUtils;
import org.springframework.security.crypto.util.EncodingUtils;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;

/**
 * @author Jonsy
 *
 */
@Component
public class JwsTokenService implements Serializable {

    private static final String SEPARATER = "\\.";

    private static final String ENCODING = "UTF-8";

    public final Base64.Decoder decoder = Base64.getDecoder();

    public JwsToken parse(String token) {
        String[] parts = token.split(SEPARATER);
        if (parts.length != 2) {
            return null;
        }

        String payload = new String(decoder.decode(parts[0]));
        JwsToken jwsToken = JSON.parseObject(payload, JwsToken.class);
        if (!jwsToken.isRight()) {
            return null;
        }

        String sign = new String(decoder.decode(parts[1]));
        if (StringUtils.isEmpty(sign)) {
            return null;
        }

        jwsToken.setSign(sign);

        return jwsToken;
    }

    public static void main(String[] args) {
        JwsToken jwsToken = new JwsTokenService().parse("eyJ1c2VyTmFtZSI6Imh1b2RvbmciLCJkZXZpY2VJZCI6ImpsanNsZGppZXgwMDIzamMifQ==.OTB1M2prYzd1amU=");
    }
}