package cn.rankin.cmsweb.service.trade.order;

import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.data.api.trade.dto.OrderDTO;
import cn.rankin.data.api.trade.dto.OrderDetailSearchDTO;
import cn.rankin.data.api.trade.entity.Order;
import cn.rankin.data.api.trade.entity.OrderDetail;
import cn.rankin.data.api.trade.entity.OrderProductSnapshot;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@FeignClient(name = "${service.trade.name}")
public interface OrderClient {

    // 此处返回值不用Vo，需要进一步处理
    @RequestMapping(value = "/order/list", method = RequestMethod.GET)
    APIResult<Page<Order>> search(@RequestParam Map<String, Object> searchDTO);

    @RequestMapping(value = "/order", method = RequestMethod.POST)
    APIResult<Order> create(@RequestBody OrderDTO orderDTO);

    @RequestMapping(value = "/order/{orderId}", method = RequestMethod.GET)
    APIResult<Order> getOrder(@PathVariable("orderId") String orderId);

    @RequestMapping(value = "/order/pay/{orderId}", method = RequestMethod.POST)
    APIResult<Boolean> pay(@PathVariable("orderId") String orderId);

    @RequestMapping(value = "/order/pay/{orderId}", method = RequestMethod.DELETE)
    APIResult<Boolean> cancel(@PathVariable("orderId") String orderId);

    @RequestMapping(value = "/order/snapshot", method = RequestMethod.GET)
    APIResult<Page<OrderProductSnapshot>> searchSnapshot(@RequestParam Map<String, Object> searchDTO);

    @RequestMapping(value = "/order/detail", method = RequestMethod.POST)
    APIResult<Page<OrderDetail>> searchDetail(@RequestBody OrderDetailSearchDTO searchDTO);
}
