package cn.rankin.common.utils.util;

import cn.rankin.common.utils.api.model.BaseCode;
import cn.rankin.common.utils.api.model.APICode;
import cn.rankin.common.utils.api.model.APIResult;
import com.alibaba.fastjson.JSON;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpMethod;
import org.springframework.security.web.util.matcher.AntPathRequestMatcher;
import org.springframework.security.web.util.matcher.RequestMatcher;
import org.springframework.util.StringUtils;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by tomas on 2017/6/4.
 */

public class HttpUtil {

    public  static List<RequestMatcher> ignoreRequest = new ArrayList<>();

    private static final Logger logger = LoggerFactory.getLogger(HttpUtil.class);

    public static void ok(HttpServletRequest request, HttpServletResponse response) {
        responseOutWithJson(request, response, APIResult.ok());
    }
    public static void error(HttpServletRequest request, HttpServletResponse response, BaseCode code) {
        if(code.getCode() == APICode._C_OK){
            responseOutWithJson(request,response, APIResult.ok());
        }else {
            responseOutWithJson(request,response, APIResult.error(code));
        }
    }
    public static void responseOutWithJson(HttpServletRequest request, HttpServletResponse response, Object data) {
        //将实体对象转换为JSON Object转换
        PrintWriter out = null;
        try {
            out = response.getWriter();
            out.append(JSON.toJSONString(data));
            logger.info("url= {} 返回JSON ={} ",request.getRequestURI(), JSON.toJSONString(data));
        } catch (IOException e) {
            logger.error("request ={} 返回 失败 e={}" ,request.getRequestURI(),e);
        } finally {
            if (out != null) {
                out.close();
            }
        }
    }

    public static void delCookies(HttpServletRequest request, HttpServletResponse response, String...  cookies) {
        for (String cookieName : cookies) {
            Cookie cookie = new Cookie(cookieName, null);
            String cookiePath = request.getContextPath();
            if (!StringUtils.hasLength(cookiePath)) {
                cookiePath = "/";
            }
            cookie.setPath(cookiePath);
            cookie.setMaxAge(0);
            response.addCookie(cookie);
        }
    }

    public static void antMatchers(HttpMethod httpMethod, String... antPatterns) {
        String method = httpMethod == null?null:httpMethod.toString();
        List<RequestMatcher> matchers = new ArrayList();
        String[] patterns = antPatterns;
        int length = antPatterns.length;

        for(int i = 0; i < length; ++i) {
            String pattern = patterns[i];
            matchers.add(new AntPathRequestMatcher(pattern, method));
        }
        ignoreRequest.addAll(matchers);
    }
    public static RequestMatcher[] getMatchersArray() {
       return ignoreRequest.toArray(new RequestMatcher[ignoreRequest.size()]);
    }

    public static String getClientIp(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (StringUtils.isEmpty(ip)) {
            return null;
        }

        return ip.split(",")[0];
    }

}
